# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# VAT
class VatSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat'
        model = models.Vat
        fields = '__all__'


class VatListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_list'
        model = models.Vat
        fields = ("code", "name", "slug", "description", "aliquot_perc", "deduct_perc", "status", "ordering")


class VatRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_retrieve'
        model = models.Vat
        fields = ("code", "name", "slug", "description", "aliquot_perc", "deduct_perc", "status", "ordering")


class VatCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_create'
        model = models.Vat
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = VatRetrieveSerializer


class VatUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_update'
        model = models.Vat
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = VatRetrieveSerializer


class VatPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_partial_update'
        model = models.Vat
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = VatRetrieveSerializer


class VatEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_enable'
        model = models.Vat
        fields = ()
        response_serializer = VatRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class VatDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_disable'
        model = models.Vat
        fields = ()
        response_serializer = VatRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class VatLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_light'
        model = models.Vat
        fields = ('code', 'status', 'status_display',)
